Module decrypt

Module decrypt 

Structs

DecryptBackend
A backend that can decrypt data.

Traits

DecryptFullBackend
A backend that can decrypt data. This is a trait that is implemented by all backends that can decrypt data. It is implemented for all backends that implement DecryptWriteBackend and DecryptReadBackend. This trait is used by the Repository to decrypt data.
DecryptReadBackend
DecryptWriteBackend

Functions

compression_level_range
The accepted range of compression levels.
max_compression_level
The maximum compression level allowed by zstd

Type Aliases

StreamResult 🔒