#[non_exhaustive]pub enum ReadSubsetOption {
All,
Percentage(f64),
Size(u64),
IdSubSet((u32, u32)),
}Expand description
Options to specify which subset of packs will be read
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
All
Read all pack files
Percentage(f64)
Read a random subset of pack files with (approximately) the given percentage of total size
Size(u64)
Read a random subset of pack files with (approximately) the given size
IdSubSet((u32, u32))
Read a subset of packfiles based on Ids: Using (1,n) .. (n,n) in separate runs will cover all pack files
Implementations
Sourceimpl ReadSubsetOption
impl ReadSubsetOption
fn apply(self, packs: impl IntoIterator<Item = IndexPack>) -> Vec<IndexPack>
fn apply_with_rng( self, packs: impl IntoIterator<Item = IndexPack>, rng: &mut impl Rng, ) -> Vec<IndexPack>