Module progress

Module progress 

Structs

HiddenProgress
A Progress showing nothing at all
NoProgress
A dummy struct which shows no progress but only logs titles and end of a progress.
NoProgressBars
Don’t show progress bars, only log rudimentary progress information.
Progress
A progress used to indicate/update the status of something which is being processed

Enums

ProgressType
Type of progress

Traits

ProgressBars
Trait to start progress information report progress information for any rustic action which supports that.
RusticProgress
Trait to report progress information for any rustic action which supports that.