RusticProgress

Trait RusticProgress 

pub trait RusticProgress:
    Send
    + Sync
    + 'static
    + Debug {
    // Required methods
    fn is_hidden(&self) -> bool;
    fn set_length(&self, len: u64);
    fn set_title(&self, title: &str);
    fn inc(&self, inc: u64);
    fn finish(&self);
}
Trait to report progress information for any rustic action which supports that.

Implement this trait when you want to display this progress to your users.

Required Methods

fn is_hidden(&self) -> bool

Check if progress is hidden

fn set_length(&self, len: u64)

Set total length for this progress

Arguments
  • len - The total length of this progress
fn set_title(&self, title: &str)

Set title for this progress

Arguments
  • title - The title of this progress
fn inc(&self, inc: u64)

Advance progress by given increment

Arguments
  • inc - The increment to advance this progress
fn finish(&self)

Finish the progress

Implementors