KeyFile

Struct KeyFile 

pub struct KeyFile {
    pub hostname: Option<String>,
    pub username: Option<String>,
    pub created: Option<Zoned>,
    pub kdf: String,
    pub n: u32,
    pub r: u32,
    pub p: u32,
    pub data: Vec<u8>,
    pub salt: Vec<u8>,
}
Key files describe information about repository access keys.

They are usually stored in the repository under /keys/<ID>

Fields

hostname: Option<String>

Hostname where the key was created

username: Option<String>

User which created the key

created: Option<Zoned>

Creation time of the key

kdf: String

The used key derivation function (currently only scrypt)

n: u32

Parameter N for scrypt

r: u32

Parameter r for scrypt

p: u32

Parameter p for scrypt

data: Vec<u8>

The key data encrypted by scrypt

salt: Vec<u8>

The salt used with scrypt

Implementations

Source

impl KeyFile

pub fn kdf_key(&self, passwd: &impl AsRef<[u8]>) -> RusticResult<Key>

Generate a Key using the key derivation function from KeyFile and a given password

Arguments
  • passwd - The password to use for the key derivation function
Errors
  • If the parameters of the key derivation function are invalid
  • If the output length of the key derivation function is invalid
Returns

The generated key

pub fn key_from_data(&self, key: &Key) -> RusticResult<Key>

Extract a key from the data of the KeyFile using the given key. The key usually should be the key generated by kdf_key()

Arguments
  • key - The key to use for decryption
Errors
  • If the data could not be deserialized
Returns

The extracted key

pub fn key_from_password(&self, passwd: &impl AsRef<[u8]>) -> RusticResult<Key>

Extract a key from the data of the KeyFile using the key from the derivation function in combination with the given password.

Arguments
  • passwd - The password to use for the key derivation function
Errors
  • If the parameters of the key derivation function are invalid
Returns

The extracted key

pub fn generate( key: Key, passwd: &impl AsRef<[u8]>, hostname: Option<String>, username: Option<String>, with_created: bool, ) -> RusticResult<Self>

Generate a new KeyFile from a given key and password.

Arguments
  • key - The key to use for encryption
  • passwd - The password to use for the key derivation function
  • hostname - The hostname to use for the KeyFile
  • username - The username to use for the KeyFile
  • with_created - Whether to set the creation time of the KeyFile to the current time
Errors
  • If the output length of the key derivation function is invalid
  • If the KeyFile could not be serialized
Returns

The generated KeyFile

fn from_backend<B: ReadBackend>(be: &B, id: &KeyId) -> RusticResult<Self>

Get a KeyFile from the backend

Arguments
  • be - The backend to use
  • id - The id of the KeyFile
Errors
  • If the KeyFile could not be deserialized/read from the backend
Returns

The KeyFile read from the backend