pub struct IndexFile {
pub supersedes: Option<Vec<IndexId>>,
pub packs: Vec<IndexPack>,
pub packs_to_delete: Vec<IndexPack>,
}Expand description
Index files describe index information about multiple pack files.
They are usually stored in the repository under /index/<ID>
Fields
supersedes: Option<Vec<IndexId>>which other index files are superseded by this (not actively used)
packs: Vec<IndexPack>Index information about used packs
packs_to_delete: Vec<IndexPack>Index information about unused packs which are already marked for deletion
Implementations