#[non_exhaustive]pub struct BackupOptions {
pub stdin_filename: String,
pub stdin_command: Option<CommandInput>,
pub as_path: Option<PathBuf>,
pub no_scan: bool,
pub dry_run: bool,
pub parent_opts: ParentOptions,
pub ignore_save_opts: LocalSourceSaveOptions,
pub excludes: Excludes,
pub ignore_filter_opts: LocalSourceFilterOptions,
}Expand description
Options for the backup command.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stdin_filename: StringSet filename to be used when backing up from stdin
stdin_command: Option<CommandInput>Call the given command and use its output as stdin
as_path: Option<PathBuf>Manually set backup path in snapshot
no_scan: boolDon’t scan the backup source for its size - this disables ETA estimation for backup.
dry_run: boolDry-run mode: Don’t write any data or snapshot
parent_opts: ParentOptionsOptions how to use a parent snapshot
ignore_save_opts: LocalSourceSaveOptionsOptions how to save entries from a local source
excludes: Excludesexcludes
ignore_filter_opts: LocalSourceFilterOptionsOptions how to filter from a local source
Implementations
Sourceimpl BackupOptions
impl BackupOptions
Sourcepub fn stdin_filename(self, value: impl Into<String>) -> Self
pub fn stdin_filename(self, value: impl Into<String>) -> Self
Sets the stdin_filename field of this struct.
Sourcepub fn stdin_command(self, value: impl Into<Option<CommandInput>>) -> Self
pub fn stdin_command(self, value: impl Into<Option<CommandInput>>) -> Self
Sets the stdin_command field of this struct.
Sourcepub fn as_path(self, value: impl Into<Option<PathBuf>>) -> Self
pub fn as_path(self, value: impl Into<Option<PathBuf>>) -> Self
Sets the as_path field of this struct.
Sourcepub fn parent_opts(self, value: impl Into<ParentOptions>) -> Self
pub fn parent_opts(self, value: impl Into<ParentOptions>) -> Self
Sets the parent_opts field of this struct.
Sourcepub fn ignore_save_opts(self, value: impl Into<LocalSourceSaveOptions>) -> Self
pub fn ignore_save_opts(self, value: impl Into<LocalSourceSaveOptions>) -> Self
Sets the ignore_save_opts field of this struct.
Sourcepub fn excludes(self, value: impl Into<Excludes>) -> Self
pub fn excludes(self, value: impl Into<Excludes>) -> Self
Sets the excludes field of this struct.
Sourcepub fn ignore_filter_opts(
self,
value: impl Into<LocalSourceFilterOptions>,
) -> Self
pub fn ignore_filter_opts( self, value: impl Into<LocalSourceFilterOptions>, ) -> Self
Sets the ignore_filter_opts field of this struct.