CommandInput

Struct CommandInput 

pub struct CommandInput(_CommandInput);
A command to be called which can be given as CLI option as well as in config files CommandInput implements Serialize/Deserialize as well as FromStr.

Tuple Fields

0: _CommandInput

Implementations

Source

impl CommandInput

pub fn is_set(&self) -> bool

Returns if a command is set

pub fn command(&self) -> &str

Returns the command

pub fn args(&self) -> &[String]

Returns the command args

pub fn on_failure(&self) -> OnFailure

Returns the error handling for the command

pub fn run<I, K, V>( &self, context: &str, what: &str, env: I, ) -> RusticResult<()>
where I: IntoIterator<Item = (K, V)>, K: AsRef<OsStr>, V: AsRef<OsStr>,

Runs the command if it is set

Errors
  • If return status cannot be read
pub fn stdout(&self) -> RusticResult<Vec<u8>>

Runs the command and get its stdout

Returns

The stdout as Vec<u8>

Errors
  • If command cannot be executed
pub(crate) fn uses_plural_placeholders(&self) -> RusticResult<bool>

Check if the command uses plural placeholders (%ids or %paths) Returns true if the command should be executed once with all values, false if it should be executed once per pack