Grouped

Struct Grouped 

pub struct Grouped<T: Grouping> {
    pub criterion: T::Criterion,
    pub groups: Vec<Group<T>>,
}
A grouped list of items

Fields

criterion: T::Criterion

The criterion used for groupung

groups: Vec<Group<T>>

The groups

Implementations

Source

impl<T: Grouping> Grouped<T>

pub fn new(criterion: T::Criterion) -> Self

Create a new empty group of snapshots

pub fn from_items(items: Vec<T>, criterion: T::Criterion) -> Self

Crate a group of items by grouping them with criterion

pub fn try_update_with<E>( self, update: impl FnOnce(Vec<T>) -> Result<Vec<T>, E>, ) -> Result<Self, E>

Update the group using update on the Vec of items

Errors
  • If update returns an error