#[non_exhaustive]pub struct LocalSourceSaveOptions {
pub set_atime: Option<TimeOption>,
pub set_ctime: Option<TimeOption>,
pub set_devid: Option<DevIdOption>,
pub set_blockdev: Option<BlockdevOption>,
pub set_xattrs: Option<XattrOption>,
}Expand description
LocalSourceSaveOptions describes how entries from a local source will be saved in the repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.set_atime: Option<TimeOption>Set access time [default: mtime]
set_ctime: Option<TimeOption>Set changed time [default: yes]
set_devid: Option<DevIdOption>Set device ID [default: hardlink]
set_blockdev: Option<BlockdevOption>How block devices should be stored [default: special]
set_xattrs: Option<XattrOption>Set extended attributes [default: yes]
Implementations
Sourceimpl LocalSourceSaveOptions
impl LocalSourceSaveOptions
Sourcepub fn set_atime(self, value: impl Into<Option<TimeOption>>) -> Self
pub fn set_atime(self, value: impl Into<Option<TimeOption>>) -> Self
Sets the set_atime field of this struct.
Sourcepub fn set_ctime(self, value: impl Into<Option<TimeOption>>) -> Self
pub fn set_ctime(self, value: impl Into<Option<TimeOption>>) -> Self
Sets the set_ctime field of this struct.
Sourcepub fn set_devid(self, value: impl Into<Option<DevIdOption>>) -> Self
pub fn set_devid(self, value: impl Into<Option<DevIdOption>>) -> Self
Sets the set_devid field of this struct.
Sourcepub fn set_blockdev(self, value: impl Into<Option<BlockdevOption>>) -> Self
pub fn set_blockdev(self, value: impl Into<Option<BlockdevOption>>) -> Self
Sets the set_blockdev field of this struct.
Sourcepub fn set_xattrs(self, value: impl Into<Option<XattrOption>>) -> Self
pub fn set_xattrs(self, value: impl Into<Option<XattrOption>>) -> Self
Sets the set_xattrs field of this struct.
Sourceimpl LocalSourceSaveOptions
impl LocalSourceSaveOptions
Sourcepub fn map_entry(
self,
entry: DirEntry,
) -> Result<ReadSourceEntry<OpenFile>, IgnoreErrorKind>
pub fn map_entry( self, entry: DirEntry, ) -> Result<ReadSourceEntry<OpenFile>, IgnoreErrorKind>
Maps a DirEntry to a ReadSourceEntry.
Arguments
entry- TheDirEntryto map.options- options for saving entries
Errors
- If metadata could not be read.
- If the xattr of the entry could not be read.
fn to_node( self, entry: &DirEntry, m: &Metadata, meta: Metadata, ) -> Result<Node, IgnoreErrorKind>
Sourceimpl LocalSourceSaveOptions
impl LocalSourceSaveOptions
fn ctime(m: &Metadata) -> Option<Timestamp>
fn device_id(m: &Metadata) -> u64
fn hardlink(m: &Metadata) -> bool
fn user_group( m: &Metadata, ) -> (Option<u32>, Option<String>, Option<u32>, Option<String>)
fn nix_infos(m: &Metadata) -> (Option<u32>, u64, u64)
Sourcefn xattrs(path: &Path) -> Result<Vec<ExtendedAttribute>, IgnoreErrorKind>
fn xattrs(path: &Path) -> Result<Vec<ExtendedAttribute>, IgnoreErrorKind>
List ExtendedAttribute for a Node located at path
Argument
pathto theNodefor which to list attributes
Errors
- If Xattr couldn’t be listed or couldn’t be read
fn to_node_other(self, name: &OsStr, m: &Metadata, meta: Metadata) -> Node