RepositoryOptions

Struct RepositoryOptions 

#[non_exhaustive]
pub struct RepositoryOptions { pub no_cache: bool, pub cache_dir: Option<PathBuf>, pub warm_up: bool, pub warm_up_command: Option<CommandInput>, pub warm_up_wait_command: Option<CommandInput>, pub warm_up_wait: Option<SignedDuration>, pub warm_up_batch: Option<usize>, }
Options for using and opening a Repository

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
no_cache: bool

Don’t use a cache.

cache_dir: Option<PathBuf>

Use this dir as cache dir instead of the standard cache dir

warm_up: bool

Warm up needed data pack files by only requesting them without processing

warm_up_command: Option<CommandInput>

Warm up needed data pack files by running the command with %id replaced by pack id

warm_up_wait_command: Option<CommandInput>

Wait for end of warm up by running the command with %id replaced by pack id

warm_up_wait: Option<SignedDuration>

Duration (e.g. 10m) to wait after warm up

warm_up_batch: Option<usize>

Batch size for warm-up command invocations

Implementations

Source

impl RepositoryOptions

pub fn no_cache(self, value: impl Into<bool>) -> Self

Sets the no_cache field of this struct.

pub fn cache_dir(self, value: impl Into<PathBuf>) -> Self

Sets the cache_dir field of this struct.

pub fn warm_up(self, value: impl Into<bool>) -> Self

Sets the warm_up field of this struct.

pub fn warm_up_command(self, value: impl Into<CommandInput>) -> Self

Sets the warm_up_command field of this struct.

pub fn warm_up_wait_command(self, value: impl Into<CommandInput>) -> Self

Sets the warm_up_wait_command field of this struct.

pub fn warm_up_wait(self, value: impl Into<SignedDuration>) -> Self

Sets the warm_up_wait field of this struct.

pub fn warm_up_batch(self, value: impl Into<usize>) -> Self

Sets the warm_up_batch field of this struct.