ProgressBars

Trait ProgressBars 

pub trait ProgressBars:
    Debug
    + Send
    + Sync
    + 'static {
    // Required method
    fn progress(&self, progress_type: ProgressType, prefix: &str) -> Progress;
}
Trait to start progress information report progress information for any rustic action which supports that.

Implement this trait when you want to display this progress to your users.

Required Methods

fn progress(&self, progress_type: ProgressType, prefix: &str) -> Progress

Start a new progress.

Arguments
  • progress_type - The type of the progress
  • prefix - The prefix of the progress

Implementors