ReadSourceOpen

Trait ReadSourceOpen 

pub trait ReadSourceOpen {
    type Reader: Read + Send + 'static;

    // Required method
    fn open(self) -> RusticResult<Self::Reader>;
}
Trait for backends that can read and open sources. This trait is implemented by all backends that can read data and open from a source.

Required Associated Types

type Reader: Read + Send + 'static

The Reader used for this source

Required Methods

fn open(self) -> RusticResult<Self::Reader>

Opens the source.

Errors
  • If the source could not be opened.
Result

The reader used to read from the source.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl ReadSourceOpen for OpenFile

Source

impl<T: Read + Send + 'static> ReadSourceOpen for T

blanket implementation for readers