OpenFile

Struct OpenFile 

pub struct OpenFile {
    content: Vec<DataId>,
    startpoints: ContentStartpoints,
}
OpenFile stores all information needed to access the contents of a file node

Fields

content: Vec<DataId>startpoints: ContentStartpoints

Implementations

Source

impl OpenFile

pub(crate) fn from_node<S: IndexedFull>( repo: &Repository<S>, node: &Node, ) -> RusticResult<Self>

Create an OpenFile from a file Node

Arguments
  • repo - The repository to create the OpenFile for
  • node - The Node to create the OpenFile for
Errors
  • If the index for the needed data blobs cannot be read
Returns

The created OpenFile

pub fn read_at<S: IndexedFull>( &self, repo: &Repository<S>, offset: usize, length: usize, ) -> RusticResult<Bytes>

Read the OpenFile at the given offset from the repo.

Arguments
  • repo - The repository to read the OpenFile from
  • offset - The offset to read the OpenFile from
  • length - The length of the content to read from the OpenFile
Errors
  • if reading the needed blob(s) from the backend fails
Returns

The read bytes from the given offset and length. If offset is behind the end of the file, an empty Bytes is returned. If length is too large, the result up to the end of the file is returned.