pub trait RusticProgress:
Send
+ Sync
+ 'static
+ Debug {
// Required methods
fn is_hidden(&self) -> bool;
fn set_length(&self, len: u64);
fn set_title(&self, title: &str);
fn inc(&self, inc: u64);
fn finish(&self);
}Expand description
Trait to report progress information for any rustic action which supports that.
Implement this trait when you want to display this progress to your users.
Required Methods
Check if progress is hidden