pub trait ProgressBars:
Debug
+ Send
+ Sync
+ 'static {
// Required method
fn progress(&self, progress_type: ProgressType, prefix: &str) -> Progress;
}Expand description
Trait to start progress information report progress information for any rustic action which supports that.
Implement this trait when you want to display this progress to your users.