pub trait ReadSourceOpen {
type Reader: Read + Send + 'static;
// Required method
fn open(self) -> RusticResult<Self::Reader>;
}Expand description
Trait for backends that can read and open sources. This trait is implemented by all backends that can read data and open from a source.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".