pub struct OpenFile {
content: Vec<DataId>,
startpoints: ContentStartpoints,
}Expand description
OpenFile stores all information needed to access the contents of a file node
Fields
content: Vec<DataId>startpoints: ContentStartpointsImplementations
Sourceimpl OpenFile
impl OpenFile
Sourcepub(crate) fn from_node<S: IndexedFull>(
repo: &Repository<S>,
node: &Node,
) -> RusticResult<Self>
pub(crate) fn from_node<S: IndexedFull>( repo: &Repository<S>, node: &Node, ) -> RusticResult<Self>
Sourcepub fn read_at<S: IndexedFull>(
&self,
repo: &Repository<S>,
offset: usize,
length: usize,
) -> RusticResult<Bytes>
pub fn read_at<S: IndexedFull>( &self, repo: &Repository<S>, offset: usize, length: usize, ) -> RusticResult<Bytes>
Read the OpenFile at the given offset from the repo.
Arguments
repo- The repository to read theOpenFilefromoffset- The offset to read theOpenFilefromlength- The length of the content to read from theOpenFile
Errors
- if reading the needed blob(s) from the backend fails
Returns
The read bytes from the given offset and length.
If offset is behind the end of the file, an empty Bytes is returned.
If length is too large, the result up to the end of the file is returned.